@@ -12,14 +12,6 @@ class DTMainSession(DTFrame.DTMainWindow):
 	Returns:
 		没有return: 这里要填啥
 	"""	
-	
-	quitApp=Signal()
-
-	def closeEvent(self,event):
-		super().closeEvent(event)
-		self.saveWindowStatus()
-		self.saveData()
-		self.quitApp.emit()
 
 	def __init__(self, app):
 		"""DTMainSession的构造函数
@@ -64,14 +56,22 @@ class DTMainSession(DTFrame.DTMainWindow):
 			self.resize(self.UserSetting().value("WindowStatus/Size"))
 			self.move(self.UserSetting().value("WindowStatus/Pos"))
 		except:
-			pass
+			self.resize(self.minimumWidth(),self.minimumHeight())
+			self.adjustSize()
+			MoveToCenterOfScreen(self)
 	
 	def initializeSignal(self):
 		"""主窗体的action向function链接
 		注意：需要拥有全局快捷键的action，需要addAction
 		"""
 		super().initializeSignal()
-		self.actionExit.triggered.connect(self.quitApp.emit)
+		
+		self.actionExit.triggered.connect(self.quit)
+		if self.app.isQuitOnClickX():
+			self.TitleBar.btn_close.clicked.connect(self.quit)
+		else:
+			self.TitleBar.btn_close.clicked.connect(self.close)
+
 		self.actionSetting.triggered.connect(self.setting)
 		self.actionAbout.triggered.connect(self.about)
 		self.actionBoss_Key.triggered.connect(self.bossComing)
@@ -107,7 +107,10 @@ class DTMainSession(DTFrame.DTMainWindow):
 		self._MainMenu.addAction(self.actionBoss_Key)
 		self._MainMenu.addAction(self.actionExit)
 		
-	
+	def refresh(self):
+		""""改变颜色后，可能有些依赖于app.color_list的颜色要更新，在这里添加对所有窗体的刷新操作"
+		"""
+		pass
 	
 	def windowResurrection(self,reason):
 		"双击TrayIcon还原主窗体"
@@ -169,8 +172,11 @@ class DTMainSession(DTFrame.DTMainWindow):
 	
 	def saveAllEncryptData(self):
 		"saveData或者UserSetting中有加密的保存项目就要放到这里（更改密码的时候会调用这个函数）"
-		pass
-	
+		if self.app.DataDir()!=None:
+			self.app.setDataDir(self.app.DataDir())
+		if self.app.isBackupEnable() and self.app.BackupDst()!=None:
+			self.app.setBackupDst(self.app.BackupDst())
+		
 	def backup(self):
 		# 可以implement这个函数，比如先保存一下
 
@@ -188,7 +194,7 @@ class DTMainSession(DTFrame.DTMainWindow):
 					shutil.copyfile(os.path.join(self.data_dir,file),file_dst)
 		
 		backup_dst=self.app.BackupDst()
-		if backup_dst==False:
+		if backup_dst==None:
 			DTFrame.DTMessageBox(self,"Warning","Please set backup dst first!",DTIcon.Warning())
 		elif not os.path.exists(backup_dst):
 			DTFrame.DTMessageBox(self,"Warning","Backup Dst %s does not exsit!"%backup_dst,DTIcon.Warning())
@@ -207,7 +213,7 @@ class DTMainSession(DTFrame.DTMainWindow):
 			about_text+="%s: %s\n"%(key,self.UserSetting().value(key))
 		self.UserSetting().endGroup()
 
-		DTFrame.DTMessageBox(self,"About",about_text[:-1])
+		DTFrame.DTMessageBox(self,"About",about_text[:-1],icon=DTIcon.Holo01())
 	
 	def setting(self):
 		"请在继承的DTSettingSession中做到实时保存设定"
@@ -216,4 +222,9 @@ class DTMainSession(DTFrame.DTMainWindow):
 		# 必须在这里再调用一次，如果不写的话，下面会说name 'DTSession' is not defined。不知道为什么啊啊啊，明明都在DTPySide的__init__中导入过了呀？！难道又是同级包内互相调用的问题，还是__feature__的annotation暂时还有bug？
 		
 		dlg=DTSession.DTSettingSession(self, self.app)
-		dlg.exec_()
\ No newline at end of file
+		dlg.exec_()
+	
+	def quit(self):
+		self.saveWindowStatus()
+		self.saveData()
+		self.app.quit()
\ No newline at end of file
