@@ -6,5 +6,11 @@ class DTApplyButton(QPushButton):
 		super().__init__(parent)
 		self.setIcon(IconFromCurrentTheme("tool.svg"))
 		self.setFlat(True)
-		self.setIconSize(QSize(30,30))
-		self.setFixedSize(36,36)
\ No newline at end of file
+		self.setStyleSheet("""
+			border: none;
+			icon-size: 22px;
+			max-height: 26px;
+			min-height: 26px;
+			min-width: 26px;
+			max-width: 26px;
+		""")
\ No newline at end of file
